==> aroundme_0_6_2.zip: aroundme_0_6_2/aroundme/language/1/barnraiser_01/setup.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common.lang.php');


//HEADER
$lang['hdr_setup'] = 							"Your account";
$lang['txt_messaging'] = 						"messaging and email";
$lang['hdr_persona'] = 							"Your persona";
$lang['hdr_network'] = 							"Build your network";
$lang['hdr_preferences'] = 						"Your preferences";


//MENU
$lang['menu_persona'] = 						"Persona";
$lang['menu_network'] = 						"Network";
$lang['menu_preferences'] = 					"Preferences";
$lang['menu_setup'] = 							"Go!";


//SUBMIT BUTTONS
$lang['sub_finish'] = 							"GO!";
$lang['sub_next'] = 							"NEXT &raquo;";


//A HREF TAGS (links)
$lang['href_index'] = 							"go to the login page";


//BODY TEXT
$lang['txt_invite'] =							"You have been invited into AROUNDMe!";
$lang['txt_invite_message_txt'] =				"Join me in AROUNDMe!";
$lang['txt_access_code'] = 						"enter your access code";
$lang['txt_access_code_help'] =					"You were sent an email with an access code. Enter the code here.";
$lang['txt_create_password'] = 					"create your password";
$lang['txt_create_password_help'] =				"Use a password that no one will guess. It has to be at least 5 characters long and with no spaces. Remember that it will be case sensitive, so 'Barnraiser' is not the same as 'barnraiser'.";
$lang['txt_password1'] = 						"Type in a password.";
$lang['txt_password2'] = 						"Repeat your password.";
$lang['txt_hi'] = 								"Hi"; //a greeting, Hi Tom,
$lang['txt_already_setup'] = 					"You've already set up with us. Click the link below.";
$lang['txt_messaging_help'] = 					"Would you like to set your default profile to allow people can send you messages?";
$lang['txt_email_message_help'] = 				"Would you like us to send you a notification email when you receive a message?";
$lang['txt_digest_newsletter_help'] = 			"Would you like us to send you a weekly newsletter containing the latest updates and statistics.";
$lang['txt_personas_intro'] = 					"Your persona is made up of a combination of your true self and your alias. Your alias is shown by default to all members of this network. You can choose to reveal your true self to close relations within this network. <b>Do not put anything into your alias that you do not with EVERYONE to see!</b>";
$lang['txt_true_self'] = 						"Your true self";
$lang['txt_alias'] = 							"Your alias";
$lang['txt_hometown'] = 						"Place of residence";
$lang['txt_female'] = 							"Female";
$lang['txt_gender'] = 							"Gender";
$lang['txt_none'] = 							"undisclosed";
$lang['txt_male'] = 							"male";
$lang['txt_nickname'] = 						"Nickname";
$lang['txt_firstname'] = 						"first name";
$lang['txt_surname'] = 							"surname";
$lang['txt_network_intro'] =					"You can invite in some friends to your network straight away. Simply type in a few of your friends email addresses. You can either put one of each line or use a comma (,) between them like 'support@barnraiser.org, info@barnraiser.org'.";
$lang['txt_hack'] = 							"We have no record of the email address that you are attempting to set up with us. Please use the link emailed to you to complete setup.";

// MESSAGES AND EMAIL
$lang['subject_im_welcome'] = 						"Welcome!";
$lang['subject_im_joined'] = 						"You've been joined";

?>

==> aroundme_0_6_5.zip: aroundme_0_6_5/aroundme/language/1/barnraiser_01/setup.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

//HEADER
$lang['hdr_setup'] = 							"Your account";
$lang['txt_messaging'] = 						"messaging and email";
$lang['hdr_persona'] = 							"Your persona";
$lang['hdr_network'] = 							"Build your network";
$lang['hdr_preferences'] = 						"Your preferences";


//MENU
$lang['menu_persona'] = 						"Persona";
$lang['menu_network'] = 						"Network";
$lang['menu_preferences'] = 					"Preferences";
$lang['menu_setup'] = 							"Go!";


//SUBMIT BUTTONS
$lang['sub_finish'] = 							"GO!";
$lang['sub_next'] = 							"NEXT &raquo;";


//A HREF TAGS (links)
$lang['href_index'] = 							"go to the login page";


//BODY TEXT
$lang['txt_dob'] = 								"Date of birth";
$lang['txt_dob_help'] = 						"If you ever forget your password we will ask you for your correct date of birth before we issue you a new password. This date is NEVER displayed.";
$lang['txt_invite'] =							"You have been invited into AROUNDMe!";
$lang['txt_invite_message_txt'] =				"Join me in AROUNDMe!";
$lang['txt_access_code'] = 						"enter your access code";
$lang['txt_access_code_help'] =					"You were sent an email with an access code. Enter the code here.";
$lang['txt_create_password'] = 					"create your password";
$lang['txt_create_password_help'] =				"Use a password that no one will guess. It has to be at least 5 characters long and with no spaces. Remember that it will be case sensitive, so 'Barnraiser' is not the same as 'barnraiser'.";
$lang['txt_password1'] = 						"Type in a password.";
$lang['txt_password2'] = 						"Repeat your password.";
$lang['txt_hi'] = 								"Hi"; //a greeting, Hi Tom,
$lang['txt_already_setup'] = 					"You've already set up with us. Click the link below.";
$lang['txt_messaging_help'] = 					"Would you like to set your default profile to allow people can send you messages?";
$lang['txt_email_message_help'] = 				"Would you like us to send you a notification email when you receive a message?";
$lang['txt_digest_newsletter_help'] = 			"Would you like us to send you a weekly newsletter containing the latest updates and statistics.";
$lang['txt_personas_intro'] = 					"Your persona is made up of a combination of your true self and your alias. Your alias is shown by default to all members of this network. You can choose to reveal your true self to close relations within this network. <b>Do not put anything into your alias that you do not with EVERYONE to see!</b>";
$lang['txt_true_self'] = 						"Your true self";
$lang['txt_alias'] = 							"Your alias";
$lang['txt_hometown'] = 						"Place of residence";
$lang['txt_female'] = 							"Female";
$lang['txt_gender'] = 							"Gender";
$lang['txt_none'] = 							"undisclosed";
$lang['txt_male'] = 							"male";
$lang['txt_nickname'] = 						"Nickname";
$lang['txt_firstname'] = 						"first name";
$lang['txt_surname'] = 							"surname";
$lang['txt_network_intro'] =					"You can invite in some friends to your network straight away. Simply type in a few of your friends email addresses. You can either put one of each line or use a comma (,) between them like 'support@barnraiser.org, info@barnraiser.org'.";
$lang['txt_hack'] = 							"We have no record of the email address that you are attempting to set up with us. Please use the link emailed to you to complete setup.";

// MESSAGES AND EMAIL
$lang['subject_im_welcome'] = 						"Welcome!";
$lang['subject_im_joined'] = 						"You've been joined";

?>
